/* -*- Mode: javascript; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

var gTestfile = 'regress-354878.js';
//-----------------------------------------------------------------------------
var BUGNUMBER = 354878;
var summary = 'decompilation of |if(0) { LABEL: const x;}|';
var actual = '';
var expect = '';


//-----------------------------------------------------------------------------
test();
//-----------------------------------------------------------------------------

function test()
{
  enterFunc ('test');
  printBugNumber(BUGNUMBER);
  printStatus (summary);
 
  var f = function () { if(0) { L: const x; } return x; }
  expect = 'function () { if(false) { L: const x; } return x; }';
  actual = f + '';
  compareSource(expect, actual, summary);

  exitFunc ('test');
}
